==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/rds/DatabaseSecret.java <==
package software.amazon.awscdk.services.rds;

/**
 * (experimental) A database secret.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:32.017Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_rds.DatabaseSecret")
public class DatabaseSecret extends software.amazon.awscdk.services.secretsmanager.Secret {

    protected DatabaseSecret(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DatabaseSecret(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DatabaseSecret(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.DatabaseSecretProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.rds.DatabaseSecret}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.rds.DatabaseSecret> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.rds.DatabaseSecretProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.rds.DatabaseSecretProps.Builder();
        }

        /**
         * (experimental) The username.
         * <p>
         * @return {@code this}
         * @param username The username. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder username(final java.lang.String username) {
            this.props.username(username);
            return this;
        }

        /**
         * (experimental) The KMS key to use to encrypt the secret.
         * <p>
         * Default: default master key
         * <p>
         * @return {@code this}
         * @param encryptionKey The KMS key to use to encrypt the secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.IKey encryptionKey) {
            this.props.encryptionKey(encryptionKey);
            return this;
        }

        /**
         * (experimental) Characters to not include in the generated password.
         * <p>
         * Default: " %+~`#$&*()|[]{}:;<>?!'/
         * <p>
         * @return {@code this}
         * @param excludeCharacters Characters to not include in the generated password. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder excludeCharacters(final java.lang.String excludeCharacters) {
            this.props.excludeCharacters(excludeCharacters);
            return this;
        }

        /**
         * (experimental) The master secret which will be used to rotate this secret.
         * <p>
         * Default: - no master secret information will be included
         * <p>
         * @return {@code this}
         * @param masterSecret The master secret which will be used to rotate this secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder masterSecret(final software.amazon.awscdk.services.secretsmanager.ISecret masterSecret) {
            this.props.masterSecret(masterSecret);
            return this;
        }

        /**
         * (experimental) Whether to replace this secret when the criteria for the password change.
         * <p>
         * This is achieved by overriding the logical id of the AWS::SecretsManager::Secret
         * with a hash of the options that influence the password generation. This
         * way a new secret will be created when the password is regenerated and the
         * cluster or instance consuming this secret will have its credentials updated.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param replaceOnPasswordCriteriaChanges Whether to replace this secret when the criteria for the password change. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder replaceOnPasswordCriteriaChanges(final java.lang.Boolean replaceOnPasswordCriteriaChanges) {
            this.props.replaceOnPasswordCriteriaChanges(replaceOnPasswordCriteriaChanges);
            return this;
        }

        /**
         * (experimental) A name for the secret.
         * <p>
         * Default: - A name is generated by CloudFormation.
         * <p>
         * @return {@code this}
         * @param secretName A name for the secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secretName(final java.lang.String secretName) {
            this.props.secretName(secretName);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.rds.DatabaseSecret}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.rds.DatabaseSecret build() {
            return new software.amazon.awscdk.services.rds.DatabaseSecret(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/rds/DatabaseSecret.java <==
package software.amazon.awscdk.services.rds;

/**
 * A database secret.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * DatabaseInstance instance;
 * DatabaseSecret myUserSecret = DatabaseSecret.Builder.create(this, "MyUserSecret")
 *         .username("myuser")
 *         .secretName("my-user-secret") // optional, defaults to a CloudFormation-generated name
 *         .masterSecret(instance.getSecret())
 *         .excludeCharacters("{}[]()'\"/\\")
 *         .build();
 * ISecret myUserSecretAttached = myUserSecret.attach(instance); // Adds DB connections information in the secret
 * instance.addRotationMultiUser("MyUser", RotationMultiUserOptions.builder() // Add rotation using the multi user scheme
 *         .secret(myUserSecretAttached).build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:12.229Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_rds.DatabaseSecret")
public class DatabaseSecret extends software.amazon.awscdk.services.secretsmanager.Secret {

    protected DatabaseSecret(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DatabaseSecret(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DatabaseSecret(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.rds.DatabaseSecretProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.rds.DatabaseSecret}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.rds.DatabaseSecret> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.rds.DatabaseSecretProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.rds.DatabaseSecretProps.Builder();
        }

        /**
         * The username.
         * <p>
         * @return {@code this}
         * @param username The username. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder username(final java.lang.String username) {
            this.props.username(username);
            return this;
        }

        /**
         * The KMS key to use to encrypt the secret.
         * <p>
         * Default: default master key
         * <p>
         * @return {@code this}
         * @param encryptionKey The KMS key to use to encrypt the secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.IKey encryptionKey) {
            this.props.encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Characters to not include in the generated password.
         * <p>
         * Default: " %+~`#$&*()|[]{}:;<>?!'/
         * <p>
         * @return {@code this}
         * @param excludeCharacters Characters to not include in the generated password. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder excludeCharacters(final java.lang.String excludeCharacters) {
            this.props.excludeCharacters(excludeCharacters);
            return this;
        }

        /**
         * The master secret which will be used to rotate this secret.
         * <p>
         * Default: - no master secret information will be included
         * <p>
         * @return {@code this}
         * @param masterSecret The master secret which will be used to rotate this secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder masterSecret(final software.amazon.awscdk.services.secretsmanager.ISecret masterSecret) {
            this.props.masterSecret(masterSecret);
            return this;
        }

        /**
         * Whether to replace this secret when the criteria for the password change.
         * <p>
         * This is achieved by overriding the logical id of the AWS::SecretsManager::Secret
         * with a hash of the options that influence the password generation. This
         * way a new secret will be created when the password is regenerated and the
         * cluster or instance consuming this secret will have its credentials updated.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param replaceOnPasswordCriteriaChanges Whether to replace this secret when the criteria for the password change. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder replaceOnPasswordCriteriaChanges(final java.lang.Boolean replaceOnPasswordCriteriaChanges) {
            this.props.replaceOnPasswordCriteriaChanges(replaceOnPasswordCriteriaChanges);
            return this;
        }

        /**
         * A list of regions where to replicate this secret.
         * <p>
         * Default: - Secret is not replicated
         * <p>
         * @return {@code this}
         * @param replicaRegions A list of regions where to replicate this secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder replicaRegions(final java.util.List<? extends software.amazon.awscdk.services.secretsmanager.ReplicaRegion> replicaRegions) {
            this.props.replicaRegions(replicaRegions);
            return this;
        }

        /**
         * A name for the secret.
         * <p>
         * Default: - A name is generated by CloudFormation.
         * <p>
         * @return {@code this}
         * @param secretName A name for the secret. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder secretName(final java.lang.String secretName) {
            this.props.secretName(secretName);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.rds.DatabaseSecret}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.rds.DatabaseSecret build() {
            return new software.amazon.awscdk.services.rds.DatabaseSecret(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
